# External Dependencies

This file lists the dependencies used in this repository.

| Dependency | License |
|-|-|
| Go | BSD 3-Clause "New" or "Revised" License |
| github.com/nats-io/nats-server/v2 | Apache License 2.0 |
| github.com/google/go-tpm | Apache License 2.0 |
| github.com/klauspost/compress | BSD 3-Clause "New" or "Revised" License |
| github.com/minio/highwayhash | Apache License 2.0 |
| github.com/nats-io/jwt/v2 | Apache License 2.0 |
| github.com/nats-io/nats.go | Apache License 2.0 |
| github.com/nats-io/nkeys | Apache License 2.0 |
| github.com/nats-io/nuid  | Apache License 2.0 |
| go.uber.org/automaxprocs | MIT License |
| golang.org/x/crypto | BSD 3-Clause "New" or "Revised" License |
| golang.org/x/sys | BSD 3-Clause "New" or "Revised" License |
| golang.org/x/time | BSD 3-Clause "New" or "Revised" License |
